@@ -25,8 +25,8 @@
 #define ARCH_UINT64_TYPE unsigned long long
 #define ARCH_INT64_PRINTF_FORMAT "ll"
 #define ARCH_BIG_ENDIAN
-#undef ARCH_ALIGN_DOUBLE
-#undef ARCH_ALIGN_INT64
+#define ARCH_ALIGN_DOUBLE
+#define ARCH_ALIGN_INT64
 #undef NONSTANDARD_DIV_MOD
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/local/lib/ocaml"
@@ -67,6 +67,7 @@
 #define HAS_SETSID
 #define HAS_PUTENV
 #define HAS_LOCALE
+#define SUPPORT_DYNAMIC_LINKING
 #define HAS_MMAP
 #define HAS_SIGWAIT
 
