@@ -6,47 +6,50 @@
 /*                                                                     */
 /*  Copyright 2000 Institut National de Recherche en Informatique et   */
 /*  en Automatique.  All rights reserved.  This file is distributed    */
-/*  under the terms of the GNU Library General Public License.         */
+/*  under the terms of the GNU Library General Public License, with    */
+/*  the special exception on linking described in file ../LICENSE.     */
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: custom.h,v 1.3 2000/02/11 15:09:22 xleroy Exp $ */
+/* $Id: custom.h,v 1.13 2005/09/22 14:21:50 xleroy Exp $ */
 
-#ifndef _custom_
-#define _custom_
+#ifndef CAML_CUSTOM_H
+#define CAML_CUSTOM_H
 
 
+#ifndef CAML_NAME_SPACE
+#include "compatibility.h"
+#endif
 #include "mlvalues.h"
 
 struct custom_operations {
   char *identifier;
   void (*finalize)(value v);
   int (*compare)(value v1, value v2);
-  long (*hash)(value v);
+  intnat (*hash)(value v);
   void (*serialize)(value v, 
-                    /*out*/ unsigned long * wsize_32 /*size in bytes*/,
-                    /*out*/ unsigned long * wsize_64 /*size in bytes*/);
-  unsigned long (*deserialize)(void * dst);
+                    /*out*/ uintnat * wsize_32 /*size in bytes*/,
+                    /*out*/ uintnat * wsize_64 /*size in bytes*/);
+  uintnat (*deserialize)(void * dst);
 };
 
 #define custom_finalize_default NULL
-extern int custom_compare_default(value v1, value v2);
+#define custom_compare_default NULL
 #define custom_hash_default NULL
-extern void custom_serialize_default(value v, unsigned long * wsize_32,
-                                     unsigned long * wsize_64);
+#define custom_serialize_default NULL
 #define custom_deserialize_default NULL
 
 #define Custom_ops_val(v) (*((struct custom_operations **) (v)))
 
-value alloc_custom(struct custom_operations * ops,
-                   unsigned long size, /*size in bytes*/
-                   mlsize_t mem, /*resources consumed*/
-                   mlsize_t max  /*max resources*/);
+CAMLextern value caml_alloc_custom(struct custom_operations * ops,
+                                   uintnat size, /*size in bytes*/
+                                   mlsize_t mem, /*resources consumed*/
+                                   mlsize_t max  /*max resources*/);
 
-void register_custom_operations(struct custom_operations * ops);
-struct custom_operations * find_custom_operations(char * ident);
-struct custom_operations * final_custom_operations(void (*fn)(value));
+CAMLextern void caml_register_custom_operations(struct custom_operations * ops);
 
-void init_custom_operations(void);
+CAMLextern int caml_compare_unordered;
+  /* Used by custom comparison to report unordered NaN-like cases. */
 
-#endif
+
+#endif /* CAML_CUSTOM_H */
