@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: memory.h,v 1.54 2005/10/14 16:40:48 xleroy Exp $ */
+/* $Id: memory.h,v 1.54.2.3 2006/07/25 09:13:16 doligez Exp $ */
 
 /* Allocation macros and functions */
 
@@ -216,8 +216,9 @@ CAMLextern struct caml__roots_block *caml_local_roots;  /* defined in roots.c */
 }while (0)
 
 #define CAMLreturn(result) do{ \
+  value caml__temp_result = (result); \
   caml_local_roots = caml__frame; \
-  return (result); \
+  return (caml__temp_result); \
 }while(0)
 
 #define CAMLnoreturn ((void) caml__frame)
