@@ -6,11 +6,12 @@
 (*                                                                     *)
 (*  Copyright 1996 Institut National de Recherche en Informatique et   *)
 (*  en Automatique.  All rights reserved.  This file is distributed    *)
-(*  under the terms of the GNU Library General Public License.         *)
+(*  under the terms of the GNU Library General Public License, with    *)
+(*  the special exception on linking described in file ../LICENSE.     *)
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: stack.ml,v 1.6 2000/04/13 12:16:02 xleroy Exp $ *)
+(* $Id: stack.ml,v 1.9 2002/06/27 08:48:26 xleroy Exp $ *)
 
 type 'a t = { mutable c : 'a list }
 
@@ -20,6 +21,8 @@ let create () = { c = [] }
 
 let clear s = s.c <- []
 
+let copy s = { c = s.c }
+
 let push x s = s.c <- x :: s.c
 
 let pop s =
@@ -32,6 +35,8 @@ let top s =
     hd::_ -> hd
   | []     -> raise Empty
 
+let is_empty s = (s.c = [])
+
 let length s = List.length s.c
 
 let iter f s = List.iter f s.c
